# Example design for the EFM03

This design demonstrates the capabilities of the EFM03 FPGA module. It was
created with Vivado 2021.2.

## Build System

### Generating the Vivado Project

Due to portability problems with full Vivado projects, this design is shipped
as a TCL script creating the Vivado project on your system.  Therefore, you
have to restore the project from the TCL script before you can use it.

The following method should work on all systems that Vivado supports.
`/path/to/efm03_exdes` is used as a placeholder for the directory that
contains the `create_project.tcl` (and this `README.md`). It needs to be
adjusted to your own setup. On Windows, the path might be something like
`C:/work/efm03` (note the forward slashes!) and on Linux something like
`/home/user/work/efm03`.

To restore the project, do the following:

- Open a Vivado TCL shell (also available in the Vivado GUI)
- Enter in the TCL shell:
    - `cd /path/to/efm03_exdes`
    - `source ./create_project.tcl`
- The project should now exist in `/path/to/efm03_exdes/EFM03_exdes`. You can
  open it using the TCL command: `open_project EFM03_exdes/EFM03_exdes.xpr`

### Updating the project TCL script

The `create_project.tcl` is can be updated from a modified `EFM03_exdes.xpr`
project using the TCL shell:

- Open the Vivado project: `open_project EFM03_exdes/EFM03_exdes.xpr`
- Run the update script: `source ./update_project.tcl`

The `create_project.tcl` is then replaced by a version representing the current
state of your local project.

#### Caveats

Some precautions have to be followed to get a clean `create_project.tcl` out of
this process. Otherwise, the project might not be restorable on another
computer because some files are missing.

Before sourcing `update_project.tcl`, do the following:

- make sure all sources (HDL, block designs, etc.) are stored outside of the
  (generated) `EFM03_exdes` directory.
- reset all design runs.
- remove the Design Checkpoint file `efm03_wrapper.dcp` (located in _Utility
  Sources/utils_1/Design Checkpoint_) from the project.

### Command line flow for Linux

The repository contains some convenience scripts for a full command-line based
build flow. These are only available for Linux so far.

#### Prerequisites

The build system expects a Vivado wrapper script in your `$PATH` called
`xilinx_2021.2` that helps it to locate the Xilinx toolchain. For example, you
could save the following as `/usr/local/bin/xilinx_2021.2`:

```bash
#!/bin/bash

source /opt/Xilinx/Vivado/2021.2/settings64.sh

export LANG=C.UTF-8
export LC_NUMERIC=C.UTF-8

exec $@
```

Of course, the path to `settings64.sh` has to be adapted to your system.

#### Preparing the Vivado Project

The Vivado project needs to be regenerated before it can be used. You can do so by running

```bash
./project.sh prepare
```

This creates a Vivado project in the `EFM03_exdes` subdirectory.

#### Building the Bitfiles

To build the project, run

```bash
./project.sh build
```

The generated files will be in `EFM03_exdes` in the usual Vivado project structure.

#### Opening the GUI

For inspection, you might want to open the project in the Vivado GUI. That can be done with

```bash
./project.sh gui
```
