#------------------------------------------------------------------------------------------------------------------------------------
#------------------------------------------------------------------------------------------------------------------------------------
# IMPORTANT NOTE:
# DO NOT CHANGE THESE CONSTRAINTS
# AXI-FX3-Interface Constraints
#------------------------------------------------------------------------------------------------------------------------------------
#------------------------------------------------------------------------------------------------------------------------------------
set_property PACKAGE_PIN K15 [get_ports i_reset]
set_property IOSTANDARD LVCMOS33 [get_ports i_reset]

# Timing Constraints on signals related to FX3 Chipset
# Loopback Clock
# Generated clock constraint for the loopback clock o_user_clk
set_property PACKAGE_PIN N21 [get_ports o_user_clk]
set_property IOSTANDARD LVCMOS33 [get_ports o_user_clk]

# Input Clock from Hardware Loopback
set_property PACKAGE_PIN M21 [get_ports i_fx3_pclk]
set_property IOSTANDARD LVCMOS33 [get_ports i_fx3_pclk]
create_clock -period 10.000 -name i_fx3_pclk -waveform {0.000 5.000} -add [get_ports i_fx3_pclk]

create_generated_clock -name o_fx3_pclk -source [get_pins -filter REF_PIN_NAME=~sys_clk* -of [get_cells -hier axi_fx3_if*]] -multiply_by 1 [get_ports o_user_clk]

# FX3 Data Output Delay Constraints
# FX3 Clock to Data Out delay is 8ns, so 2ns before THIS clock edge or 8ns AFTER the PREVIOUS Clock edge
# FX3 needs 8ns to setup its data..!!
#set_input_delay -clock [get_clocks -of_objects [get_pins efm03_i/clk_wiz_0/inst/mmcm_adv_inst/CLKOUT0]] -max 8.000 [get_ports io_fx3_fdata]
set_input_delay -clock i_fx3_pclk -max 8.000 [get_ports io_fx3_fdata]
# FX3 Data Hold is 2ns, so 2ns after THIS clock edge
#set_input_delay -clock [get_clocks -of_objects [get_pins efm03_i/clk_wiz_0/inst/mmcm_adv_inst/CLKOUT0]] -min 2.000 [get_ports io_fx3_fdata]
set_input_delay -clock i_fx3_pclk -min 2.000 [get_ports io_fx3_fdata]


# FX3 Data Input Delay Constraints
# FX3 Data Input SETUP is 2 ns, so max is 2
set_output_delay -clock o_fx3_pclk -max 2.000 [get_ports io_fx3_fdata]
# FX3 Data Input HOLD is 2 ns, so min is 0.5
set_output_delay -clock o_fx3_pclk -min -0.500 [get_ports io_fx3_fdata]


# FX3 Control Signal Constraints
# FX3 CTRL Input SETUP is 2 ns, so max is 2
set_output_delay -clock o_fx3_pclk -max 2.000 [get_ports o_fx3_slcs_n]
set_output_delay -clock o_fx3_pclk -min -0.500 [get_ports o_fx3_slcs_n]

set_output_delay -clock o_fx3_pclk -max 2.000 [get_ports o_fx3_slwr_n]
set_output_delay -clock o_fx3_pclk -min -0.500 [get_ports o_fx3_slwr_n]

set_output_delay -clock o_fx3_pclk -max 2.000 [get_ports o_fx3_slrd_n]
set_output_delay -clock o_fx3_pclk -min -0.500 [get_ports o_fx3_slrd_n]

set_output_delay -clock o_fx3_pclk -max 2.000 [get_ports o_fx3_sloe_n]
set_output_delay -clock o_fx3_pclk -min -0.500 [get_ports o_fx3_sloe_n]

set_output_delay -clock o_fx3_pclk -max 2.000 [get_ports o_fx3_pktend_n]
set_output_delay -clock o_fx3_pclk -min -0.500 [get_ports o_fx3_pktend_n]

set_output_delay -clock o_fx3_pclk -max 2.000 [get_ports o_fx3_faddr]
set_output_delay -clock o_fx3_pclk -min -0.500 [get_ports o_fx3_faddr]
# *---------------------------------------------------------------------------

set_property SLEW FAST [get_ports o_fx3_slcs_n]
set_property SLEW FAST [get_ports o_fx3_sloe_n]
set_property SLEW FAST [get_ports o_fx3_slrd_n]
set_property SLEW FAST [get_ports o_fx3_slwr_n]
set_property SLEW FAST [get_ports {io_fx3_fdata[31]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[30]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[29]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[28]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[27]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[26]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[25]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[24]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[23]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[22]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[21]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[20]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[19]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[18]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[17]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[16]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[15]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[14]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[13]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[12]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[11]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[10]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[9]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[8]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[7]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[6]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[5]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[4]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[3]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[2]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[1]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[0]}]

set_property DRIVE 16 [get_ports {io_fx3_fdata[31]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[30]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[29]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[28]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[27]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[26]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[25]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[24]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[23]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[22]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[21]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[20]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[19]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[18]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[17]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[16]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[15]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[14]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[13]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[12]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[11]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[10]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[9]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[8]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[7]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[6]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[5]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[4]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[3]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[2]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[1]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[0]}]
set_property DRIVE 16 [get_ports o_fx3_slcs_n]
set_property DRIVE 16 [get_ports o_fx3_sloe_n]
set_property DRIVE 16 [get_ports o_fx3_slrd_n]
set_property DRIVE 16 [get_ports o_fx3_slwr_n]
set_property DRIVE 16 [get_ports o_fx3_pktend_n]
set_property DRIVE 16 [get_ports {o_fx3_faddr[1]}]
set_property DRIVE 16 [get_ports {o_fx3_faddr[0]}]

# FX3 Control Locations
set_property PACKAGE_PIN L19 [get_ports o_fx3_pktend_n]
set_property PACKAGE_PIN M22 [get_ports o_fx3_slcs_n]
set_property PACKAGE_PIN K17 [get_ports o_fx3_sloe_n]
set_property PACKAGE_PIN K16 [get_ports o_fx3_slrd_n]
set_property PACKAGE_PIN M19 [get_ports o_fx3_slwr_n]
set_property PACKAGE_PIN N22 [get_ports {o_fx3_faddr[1]}]
set_property PACKAGE_PIN P20 [get_ports {o_fx3_faddr[0]}]

set_property IOSTANDARD LVCMOS33 [get_ports o_fx3_pktend_n]
set_property IOSTANDARD LVCMOS33 [get_ports o_fx3_slcs_n]
set_property IOSTANDARD LVCMOS33 [get_ports o_fx3_sloe_n]
set_property IOSTANDARD LVCMOS33 [get_ports o_fx3_slrd_n]
set_property IOSTANDARD LVCMOS33 [get_ports o_fx3_slwr_n]
set_property IOSTANDARD LVCMOS33 [get_ports {o_fx3_faddr[1]}]
set_property IOSTANDARD LVCMOS33 [get_ports {o_fx3_faddr[0]}]

# FX3 Flag Locations
set_property PACKAGE_PIN R18 [get_ports {i_fx3_flag[3]}]
set_property PACKAGE_PIN J16 [get_ports {i_fx3_flag[2]}]
set_property PACKAGE_PIN N24 [get_ports {i_fx3_flag[1]}]
set_property PACKAGE_PIN P21 [get_ports {i_fx3_flag[0]}]
set_property IOSTANDARD LVCMOS33 [get_ports {i_fx3_flag[3]}]
set_property IOSTANDARD LVCMOS33 [get_ports {i_fx3_flag[2]}]
set_property IOSTANDARD LVCMOS33 [get_ports {i_fx3_flag[1]}]
set_property IOSTANDARD LVCMOS33 [get_ports {i_fx3_flag[0]}]

# FX3 Data Locations
set_property PACKAGE_PIN T24 [get_ports {io_fx3_fdata[0]}]
set_property PACKAGE_PIN L23 [get_ports {io_fx3_fdata[1]}]
set_property PACKAGE_PIN L22 [get_ports {io_fx3_fdata[2]}]
set_property PACKAGE_PIN L24 [get_ports {io_fx3_fdata[3]}]
set_property PACKAGE_PIN N16 [get_ports {io_fx3_fdata[4]}]
set_property PACKAGE_PIN N17 [get_ports {io_fx3_fdata[5]}]
set_property PACKAGE_PIN R16 [get_ports {io_fx3_fdata[6]}]
set_property PACKAGE_PIN R17 [get_ports {io_fx3_fdata[7]}]
set_property PACKAGE_PIN N18 [get_ports {io_fx3_fdata[8]}]
set_property PACKAGE_PIN K25 [get_ports {io_fx3_fdata[9]}]
set_property PACKAGE_PIN K26 [get_ports {io_fx3_fdata[10]}]
set_property PACKAGE_PIN M20 [get_ports {io_fx3_fdata[11]}]
set_property PACKAGE_PIN L20 [get_ports {io_fx3_fdata[12]}]
set_property PACKAGE_PIN L25 [get_ports {io_fx3_fdata[13]}]
set_property PACKAGE_PIN M24 [get_ports {io_fx3_fdata[14]}]
set_property PACKAGE_PIN M25 [get_ports {io_fx3_fdata[15]}]
set_property PACKAGE_PIN R23 [get_ports {io_fx3_fdata[16]}]
set_property PACKAGE_PIN T23 [get_ports {io_fx3_fdata[17]}]
set_property PACKAGE_PIN R22 [get_ports {io_fx3_fdata[18]}]
set_property PACKAGE_PIN T22 [get_ports {io_fx3_fdata[19]}]
set_property PACKAGE_PIN P26 [get_ports {io_fx3_fdata[20]}]
set_property PACKAGE_PIN R26 [get_ports {io_fx3_fdata[21]}]
set_property PACKAGE_PIN T25 [get_ports {io_fx3_fdata[22]}]
set_property PACKAGE_PIN M26 [get_ports {io_fx3_fdata[23]}]
set_property PACKAGE_PIN N26 [get_ports {io_fx3_fdata[24]}]
set_property PACKAGE_PIN P25 [get_ports {io_fx3_fdata[25]}]
set_property PACKAGE_PIN R25 [get_ports {io_fx3_fdata[26]}]
set_property PACKAGE_PIN R21 [get_ports {io_fx3_fdata[27]}]
set_property PACKAGE_PIN R20 [get_ports {io_fx3_fdata[28]}]
set_property PACKAGE_PIN P24 [get_ports {io_fx3_fdata[29]}]
set_property PACKAGE_PIN P23 [get_ports {io_fx3_fdata[30]}]
set_property PACKAGE_PIN N19 [get_ports {io_fx3_fdata[31]}]

set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[31]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[30]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[29]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[28]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[27]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[26]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[25]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[24]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[23]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[22]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[21]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[20]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[19]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[18]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[17]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[16]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[15]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[14]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[13]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[12]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[11]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[10]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[9]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[8]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[7]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[6]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[5]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[4]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[3]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[2]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[1]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[0]}]

#------------------------------------------------------------------------------------------------------------------------------------
# Constraints for the Reference Design
#------------------------------------------------------------------------------------------------------------------------------------
# XADC
#------------------------------------------------------------------
set_property PACKAGE_PIN P11 [get_ports vn_in]

# Flash Memory
#------------------------------------------------------------------
set_property PACKAGE_PIN R14 [get_ports o_flash_dq0]
set_property PACKAGE_PIN R15 [get_ports i_flash_dq1]
set_property PACKAGE_PIN P14 [get_ports o_flash_dq2]
set_property PACKAGE_PIN N14 [get_ports o_flash_dq3]
set_property PACKAGE_PIN P18 [get_ports o_flash_ss]

set_property IOSTANDARD LVCMOS33 [get_ports o_flash_dq0]
set_property IOSTANDARD LVCMOS33 [get_ports i_flash_dq1]
set_property IOSTANDARD LVCMOS33 [get_ports o_flash_dq2]
set_property IOSTANDARD LVCMOS33 [get_ports o_flash_dq3]
set_property IOSTANDARD LVCMOS33 [get_ports o_flash_ss]

# User LED is used to signal channel_up of the corresponding GTP QUAD


# GPIO sets
# 191 GPIOs
#------------------------------------------------------------------
#GPIO_0
set_property PACKAGE_PIN V14 [get_ports {GPIO_0_tri_io[0]}]
set_property PACKAGE_PIN U14 [get_ports {GPIO_0_tri_io[1]}]
set_property PACKAGE_PIN AC21 [get_ports {GPIO_0_tri_io[2]}]
set_property PACKAGE_PIN AB21 [get_ports {GPIO_0_tri_io[3]}]
set_property PACKAGE_PIN V26 [get_ports {GPIO_0_tri_io[4]}]
set_property PACKAGE_PIN W26 [get_ports {GPIO_0_tri_io[5]}]
set_property PACKAGE_PIN AC18 [get_ports {GPIO_0_tri_io[6]}]
set_property PACKAGE_PIN AD18 [get_ports {GPIO_0_tri_io[7]}]
set_property PACKAGE_PIN V23 [get_ports {GPIO_0_tri_io[8]}]
set_property PACKAGE_PIN W23 [get_ports {GPIO_0_tri_io[9]}]
set_property PACKAGE_PIN AA23 [get_ports {GPIO_0_tri_io[10]}]
set_property PACKAGE_PIN AA22 [get_ports {GPIO_0_tri_io[11]}]
set_property PACKAGE_PIN AB26 [get_ports {GPIO_0_tri_io[12]}]
set_property PACKAGE_PIN AC26 [get_ports {GPIO_0_tri_io[13]}]
set_property PACKAGE_PIN Y25 [get_ports {GPIO_0_tri_io[14]}]
set_property PACKAGE_PIN AA25 [get_ports {GPIO_0_tri_io[15]}]
set_property PACKAGE_PIN U26 [get_ports {GPIO_0_tri_io[16]}]
set_property PACKAGE_PIN U25 [get_ports {GPIO_0_tri_io[17]}]
set_property PACKAGE_PIN V24 [get_ports {GPIO_0_tri_io[18]}]
set_property PACKAGE_PIN W24 [get_ports {GPIO_0_tri_io[19]}]
set_property PACKAGE_PIN Y22 [get_ports {GPIO_0_tri_io[20]}]
set_property PACKAGE_PIN Y23 [get_ports {GPIO_0_tri_io[21]}]
set_property PACKAGE_PIN AB19 [get_ports {GPIO_0_tri_io[22]}]
set_property PACKAGE_PIN AA19 [get_ports {GPIO_0_tri_io[23]}]
set_property PACKAGE_PIN U22 [get_ports {GPIO_0_tri_io[24]}]
set_property PACKAGE_PIN V22 [get_ports {GPIO_0_tri_io[25]}]
set_property PACKAGE_PIN U21 [get_ports {GPIO_0_tri_io[26]}]
set_property PACKAGE_PIN V21 [get_ports {GPIO_0_tri_io[27]}]
set_property PACKAGE_PIN AB20 [get_ports {GPIO_0_tri_io[28]}]
set_property PACKAGE_PIN AA20 [get_ports {GPIO_0_tri_io[29]}]
set_property PACKAGE_PIN AF20 [get_ports {GPIO_0_tri_io[30]}]
set_property PACKAGE_PIN AF19 [get_ports {GPIO_0_tri_io[31]}]

set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_0_tri_io[31]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_0_tri_io[30]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_0_tri_io[28]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_0_tri_io[27]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_0_tri_io[26]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_0_tri_io[25]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_0_tri_io[24]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_0_tri_io[23]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_0_tri_io[22]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_0_tri_io[21]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_0_tri_io[20]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_0_tri_io[19]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_0_tri_io[18]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_0_tri_io[17]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_0_tri_io[16]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_0_tri_io[15]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_0_tri_io[14]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_0_tri_io[13]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_0_tri_io[12]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_0_tri_io[11]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_0_tri_io[10]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_0_tri_io[9]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_0_tri_io[8]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_0_tri_io[7]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_0_tri_io[6]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_0_tri_io[5]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_0_tri_io[4]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_0_tri_io[3]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_0_tri_io[2]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_0_tri_io[1]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_0_tri_io[0]}]

set_property PULLDOWN true [get_ports {GPIO_0_tri_io[31]}]
set_property PULLDOWN true [get_ports {GPIO_0_tri_io[30]}]
set_property PULLDOWN true [get_ports {GPIO_0_tri_io[29]}]
set_property PULLDOWN true [get_ports {GPIO_0_tri_io[28]}]
set_property PULLDOWN true [get_ports {GPIO_0_tri_io[27]}]
set_property PULLDOWN true [get_ports {GPIO_0_tri_io[26]}]
set_property PULLDOWN true [get_ports {GPIO_0_tri_io[25]}]
set_property PULLDOWN true [get_ports {GPIO_0_tri_io[24]}]
set_property PULLDOWN true [get_ports {GPIO_0_tri_io[23]}]
set_property PULLDOWN true [get_ports {GPIO_0_tri_io[22]}]
set_property PULLDOWN true [get_ports {GPIO_0_tri_io[21]}]
set_property PULLDOWN true [get_ports {GPIO_0_tri_io[20]}]
set_property PULLDOWN true [get_ports {GPIO_0_tri_io[19]}]
set_property PULLDOWN true [get_ports {GPIO_0_tri_io[18]}]
set_property PULLDOWN true [get_ports {GPIO_0_tri_io[17]}]
set_property PULLDOWN true [get_ports {GPIO_0_tri_io[16]}]
set_property PULLDOWN true [get_ports {GPIO_0_tri_io[15]}]
set_property PULLDOWN true [get_ports {GPIO_0_tri_io[14]}]
set_property PULLDOWN true [get_ports {GPIO_0_tri_io[13]}]
set_property PULLDOWN true [get_ports {GPIO_0_tri_io[12]}]
set_property PULLDOWN true [get_ports {GPIO_0_tri_io[11]}]
set_property PULLDOWN true [get_ports {GPIO_0_tri_io[10]}]
set_property PULLDOWN true [get_ports {GPIO_0_tri_io[9]}]
set_property PULLDOWN true [get_ports {GPIO_0_tri_io[8]}]
set_property PULLDOWN true [get_ports {GPIO_0_tri_io[7]}]
set_property PULLDOWN true [get_ports {GPIO_0_tri_io[6]}]
set_property PULLDOWN true [get_ports {GPIO_0_tri_io[5]}]
set_property PULLDOWN true [get_ports {GPIO_0_tri_io[4]}]
set_property PULLDOWN true [get_ports {GPIO_0_tri_io[3]}]
set_property PULLDOWN true [get_ports {GPIO_0_tri_io[2]}]
set_property PULLDOWN true [get_ports {GPIO_0_tri_io[1]}]
set_property PULLDOWN true [get_ports {GPIO_0_tri_io[0]}]
#------------------------------------------------------------------

#GPIO_1
set_property PACKAGE_PIN AE21 [get_ports {GPIO_1_tri_io[0]}]
set_property PACKAGE_PIN AD21 [get_ports {GPIO_1_tri_io[1]}]
set_property PACKAGE_PIN AF18 [get_ports {GPIO_1_tri_io[2]}]
set_property PACKAGE_PIN AE18 [get_ports {GPIO_1_tri_io[3]}]
set_property PACKAGE_PIN V19 [get_ports {GPIO_1_tri_io[4]}]
set_property PACKAGE_PIN W19 [get_ports {GPIO_1_tri_io[5]}]
set_property PACKAGE_PIN U19 [get_ports {GPIO_1_tri_io[6]}]
set_property PACKAGE_PIN T19 [get_ports {GPIO_1_tri_io[7]}]
set_property PACKAGE_PIN V16 [get_ports {GPIO_1_tri_io[8]}]
set_property PACKAGE_PIN V17 [get_ports {GPIO_1_tri_io[9]}]
set_property PACKAGE_PIN U15 [get_ports {GPIO_1_tri_io[10]}]
set_property PACKAGE_PIN U16 [get_ports {GPIO_1_tri_io[11]}]
set_property PACKAGE_PIN W18 [get_ports {GPIO_1_tri_io[12]}]
set_property PACKAGE_PIN V18 [get_ports {GPIO_1_tri_io[13]}]
set_property PACKAGE_PIN AE1 [get_ports {GPIO_1_tri_io[14]}]
set_property PACKAGE_PIN AD1 [get_ports {GPIO_1_tri_io[15]}]
set_property PACKAGE_PIN AF5 [get_ports {GPIO_1_tri_io[16]}]
set_property PACKAGE_PIN AF4 [get_ports {GPIO_1_tri_io[17]}]
set_property PACKAGE_PIN AE5 [get_ports {GPIO_1_tri_io[18]}]
set_property PACKAGE_PIN AD5 [get_ports {GPIO_1_tri_io[19]}]
set_property PACKAGE_PIN Y3 [get_ports {GPIO_1_tri_io[20]}]
set_property PACKAGE_PIN W3 [get_ports {GPIO_1_tri_io[21]}]
set_property PACKAGE_PIN AF3 [get_ports {GPIO_1_tri_io[22]}]
set_property PACKAGE_PIN AE3 [get_ports {GPIO_1_tri_io[23]}]
set_property PACKAGE_PIN A19 [get_ports {GPIO_1_tri_io[24]}]
set_property PACKAGE_PIN B19 [get_ports {GPIO_1_tri_io[25]}]
set_property PACKAGE_PIN AE2 [get_ports {GPIO_1_tri_io[26]}]
set_property PACKAGE_PIN AF2 [get_ports {GPIO_1_tri_io[27]}]
set_property PACKAGE_PIN AB2 [get_ports {GPIO_1_tri_io[28]}]
set_property PACKAGE_PIN AC2 [get_ports {GPIO_1_tri_io[29]}]
set_property PACKAGE_PIN A22 [get_ports {GPIO_1_tri_io[30]}]
set_property PACKAGE_PIN B22 [get_ports {GPIO_1_tri_io[31]}]

set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_0_tri_io[29]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_1_tri_io[31]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_1_tri_io[30]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_1_tri_io[29]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_1_tri_io[28]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_1_tri_io[27]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_1_tri_io[26]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_1_tri_io[25]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_1_tri_io[24]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_1_tri_io[23]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_1_tri_io[22]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_1_tri_io[21]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_1_tri_io[20]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_1_tri_io[19]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_1_tri_io[18]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_1_tri_io[17]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_1_tri_io[16]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_1_tri_io[15]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_1_tri_io[14]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_1_tri_io[13]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_1_tri_io[12]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_1_tri_io[11]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_1_tri_io[10]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_1_tri_io[9]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_1_tri_io[8]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_1_tri_io[7]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_1_tri_io[6]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_1_tri_io[5]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_1_tri_io[4]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_1_tri_io[3]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_1_tri_io[2]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_1_tri_io[1]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_1_tri_io[0]}]

set_property PULLDOWN true [get_ports {GPIO_1_tri_io[31]}]
set_property PULLDOWN true [get_ports {GPIO_1_tri_io[30]}]
set_property PULLDOWN true [get_ports {GPIO_1_tri_io[29]}]
set_property PULLDOWN true [get_ports {GPIO_1_tri_io[28]}]
set_property PULLDOWN true [get_ports {GPIO_1_tri_io[27]}]
set_property PULLDOWN true [get_ports {GPIO_1_tri_io[26]}]
set_property PULLDOWN true [get_ports {GPIO_1_tri_io[25]}]
set_property PULLDOWN true [get_ports {GPIO_1_tri_io[24]}]
set_property PULLDOWN true [get_ports {GPIO_1_tri_io[23]}]
set_property PULLDOWN true [get_ports {GPIO_1_tri_io[22]}]
set_property PULLDOWN true [get_ports {GPIO_1_tri_io[21]}]
set_property PULLDOWN true [get_ports {GPIO_1_tri_io[20]}]
set_property PULLDOWN true [get_ports {GPIO_1_tri_io[19]}]
set_property PULLDOWN true [get_ports {GPIO_1_tri_io[18]}]
set_property PULLDOWN true [get_ports {GPIO_1_tri_io[17]}]
set_property PULLDOWN true [get_ports {GPIO_1_tri_io[16]}]
set_property PULLDOWN true [get_ports {GPIO_1_tri_io[15]}]
set_property PULLDOWN true [get_ports {GPIO_1_tri_io[14]}]
set_property PULLDOWN true [get_ports {GPIO_1_tri_io[13]}]
set_property PULLDOWN true [get_ports {GPIO_1_tri_io[12]}]
set_property PULLDOWN true [get_ports {GPIO_1_tri_io[11]}]
set_property PULLDOWN true [get_ports {GPIO_1_tri_io[10]}]
set_property PULLDOWN true [get_ports {GPIO_1_tri_io[9]}]
set_property PULLDOWN true [get_ports {GPIO_1_tri_io[8]}]
set_property PULLDOWN true [get_ports {GPIO_1_tri_io[7]}]
set_property PULLDOWN true [get_ports {GPIO_1_tri_io[6]}]
set_property PULLDOWN true [get_ports {GPIO_1_tri_io[5]}]
set_property PULLDOWN true [get_ports {GPIO_1_tri_io[4]}]
set_property PULLDOWN true [get_ports {GPIO_1_tri_io[3]}]
set_property PULLDOWN true [get_ports {GPIO_1_tri_io[2]}]
set_property PULLDOWN true [get_ports {GPIO_1_tri_io[1]}]
set_property PULLDOWN true [get_ports {GPIO_1_tri_io[0]}]
#------------------------------------------------------------------

#GPIO_2
set_property PACKAGE_PIN V2 [get_ports {GPIO_2_tri_io[0]}]
set_property PACKAGE_PIN V3 [get_ports {GPIO_2_tri_io[1]}]
set_property PACKAGE_PIN B21 [get_ports {GPIO_2_tri_io[2]}]
set_property PACKAGE_PIN C21 [get_ports {GPIO_2_tri_io[3]}]
set_property PACKAGE_PIN H15 [get_ports {GPIO_2_tri_io[4]}]
set_property PACKAGE_PIN H14 [get_ports {GPIO_2_tri_io[5]}]
set_property PACKAGE_PIN W6 [get_ports {GPIO_2_tri_io[6]}]
set_property PACKAGE_PIN V6 [get_ports {GPIO_2_tri_io[7]}]
set_property PACKAGE_PIN AA7 [get_ports {GPIO_2_tri_io[8]}]
set_property PACKAGE_PIN Y7 [get_ports {GPIO_2_tri_io[9]}]
set_property PACKAGE_PIN E17 [get_ports {GPIO_2_tri_io[10]}]
set_property PACKAGE_PIN E18 [get_ports {GPIO_2_tri_io[11]}]
set_property PACKAGE_PIN AA3 [get_ports {GPIO_2_tri_io[12]}]
set_property PACKAGE_PIN AA2 [get_ports {GPIO_2_tri_io[13]}]
set_property PACKAGE_PIN D18 [get_ports {GPIO_2_tri_io[14]}]
set_property PACKAGE_PIN C18 [get_ports {GPIO_2_tri_io[15]}]
set_property PACKAGE_PIN AA4 [get_ports {GPIO_2_tri_io[16]}]
set_property PACKAGE_PIN AB4 [get_ports {GPIO_2_tri_io[17]}]
set_property PACKAGE_PIN F15 [get_ports {GPIO_2_tri_io[18]}]
set_property PACKAGE_PIN G15 [get_ports {GPIO_2_tri_io[19]}]
set_property PACKAGE_PIN B20 [get_ports {GPIO_2_tri_io[20]}]
set_property PACKAGE_PIN A20 [get_ports {GPIO_2_tri_io[21]}]
set_property PACKAGE_PIN D16 [get_ports {GPIO_2_tri_io[22]}]
set_property PACKAGE_PIN E16 [get_ports {GPIO_2_tri_io[23]}]
set_property PACKAGE_PIN AA8 [get_ports {GPIO_2_tri_io[24]}]
set_property PACKAGE_PIN Y8 [get_ports {GPIO_2_tri_io[25]}]
set_property PACKAGE_PIN C17 [get_ports {GPIO_2_tri_io[26]}]
set_property PACKAGE_PIN B17 [get_ports {GPIO_2_tri_io[27]}]
set_property PACKAGE_PIN U7 [get_ports {GPIO_2_tri_io[28]}]
set_property PACKAGE_PIN V7 [get_ports {GPIO_2_tri_io[29]}]
set_property PACKAGE_PIN G17 [get_ports {GPIO_2_tri_io[30]}]
set_property PACKAGE_PIN F17 [get_ports {GPIO_2_tri_io[31]}]

set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_2_tri_io[31]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_2_tri_io[30]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_2_tri_io[29]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_2_tri_io[28]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_2_tri_io[27]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_2_tri_io[26]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_2_tri_io[25]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_2_tri_io[24]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_2_tri_io[23]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_2_tri_io[22]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_2_tri_io[21]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_2_tri_io[20]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_2_tri_io[19]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_2_tri_io[18]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_2_tri_io[17]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_2_tri_io[16]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_2_tri_io[15]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_2_tri_io[14]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_2_tri_io[13]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_2_tri_io[12]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_2_tri_io[11]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_2_tri_io[10]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_2_tri_io[9]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_2_tri_io[8]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_2_tri_io[7]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_2_tri_io[6]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_2_tri_io[5]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_2_tri_io[4]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_2_tri_io[3]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_2_tri_io[2]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_2_tri_io[1]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_2_tri_io[0]}]

set_property PULLDOWN true [get_ports {GPIO_2_tri_io[31]}]
set_property PULLDOWN true [get_ports {GPIO_2_tri_io[30]}]
set_property PULLDOWN true [get_ports {GPIO_2_tri_io[29]}]
set_property PULLDOWN true [get_ports {GPIO_2_tri_io[28]}]
set_property PULLDOWN true [get_ports {GPIO_2_tri_io[27]}]
set_property PULLDOWN true [get_ports {GPIO_2_tri_io[26]}]
set_property PULLDOWN true [get_ports {GPIO_2_tri_io[25]}]
set_property PULLDOWN true [get_ports {GPIO_2_tri_io[24]}]
set_property PULLDOWN true [get_ports {GPIO_2_tri_io[23]}]
set_property PULLDOWN true [get_ports {GPIO_2_tri_io[22]}]
set_property PULLDOWN true [get_ports {GPIO_2_tri_io[21]}]
set_property PULLDOWN true [get_ports {GPIO_2_tri_io[20]}]
set_property PULLDOWN true [get_ports {GPIO_2_tri_io[19]}]
set_property PULLDOWN true [get_ports {GPIO_2_tri_io[18]}]
set_property PULLDOWN true [get_ports {GPIO_2_tri_io[17]}]
set_property PULLDOWN true [get_ports {GPIO_2_tri_io[16]}]
set_property PULLDOWN true [get_ports {GPIO_2_tri_io[15]}]
set_property PULLDOWN true [get_ports {GPIO_2_tri_io[14]}]
set_property PULLDOWN true [get_ports {GPIO_2_tri_io[13]}]
set_property PULLDOWN true [get_ports {GPIO_2_tri_io[12]}]
set_property PULLDOWN true [get_ports {GPIO_2_tri_io[11]}]
set_property PULLDOWN true [get_ports {GPIO_2_tri_io[10]}]
set_property PULLDOWN true [get_ports {GPIO_2_tri_io[9]}]
set_property PULLDOWN true [get_ports {GPIO_2_tri_io[8]}]
set_property PULLDOWN true [get_ports {GPIO_2_tri_io[7]}]
set_property PULLDOWN true [get_ports {GPIO_2_tri_io[6]}]
set_property PULLDOWN true [get_ports {GPIO_2_tri_io[5]}]
set_property PULLDOWN true [get_ports {GPIO_2_tri_io[4]}]
set_property PULLDOWN true [get_ports {GPIO_2_tri_io[3]}]
set_property PULLDOWN true [get_ports {GPIO_2_tri_io[2]}]
set_property PULLDOWN true [get_ports {GPIO_2_tri_io[1]}]
set_property PULLDOWN true [get_ports {GPIO_2_tri_io[0]}]
#------------------------------------------------------------------

#GPIO_3
set_property PACKAGE_PIN A25 [get_ports {GPIO_3_tri_io[0]}]
set_property PACKAGE_PIN B25 [get_ports {GPIO_3_tri_io[1]}]
set_property PACKAGE_PIN F19 [get_ports {GPIO_3_tri_io[2]}]
set_property PACKAGE_PIN F18 [get_ports {GPIO_3_tri_io[3]}]
set_property PACKAGE_PIN E21 [get_ports {GPIO_3_tri_io[4]}]
set_property PACKAGE_PIN D21 [get_ports {GPIO_3_tri_io[5]}]
set_property PACKAGE_PIN C26 [get_ports {GPIO_3_tri_io[6]}]
set_property PACKAGE_PIN B26 [get_ports {GPIO_3_tri_io[7]}]
set_property PACKAGE_PIN A18 [get_ports {GPIO_3_tri_io[8]}]
set_property PACKAGE_PIN A17 [get_ports {GPIO_3_tri_io[9]}]
set_property PACKAGE_PIN G19 [get_ports {GPIO_3_tri_io[10]}]
set_property PACKAGE_PIN F20 [get_ports {GPIO_3_tri_io[11]}]
set_property PACKAGE_PIN D23 [get_ports {GPIO_3_tri_io[12]}]
set_property PACKAGE_PIN D24 [get_ports {GPIO_3_tri_io[13]}]
set_property PACKAGE_PIN AD4 [get_ports {GPIO_3_tri_io[14]}]
set_property PACKAGE_PIN AC4 [get_ports {GPIO_3_tri_io[15]}]
set_property PACKAGE_PIN AC6 [get_ports {GPIO_3_tri_io[16]}]
set_property PACKAGE_PIN AB6 [get_ports {GPIO_3_tri_io[17]}]
set_property PACKAGE_PIN C19 [get_ports {GPIO_3_tri_io[18]}]
set_property PACKAGE_PIN D19 [get_ports {GPIO_3_tri_io[19]}]
set_property PACKAGE_PIN AC3 [get_ports {GPIO_3_tri_io[20]}]
set_property PACKAGE_PIN AD3 [get_ports {GPIO_3_tri_io[21]}]
set_property PACKAGE_PIN A24 [get_ports {GPIO_3_tri_io[22]}]
set_property PACKAGE_PIN A23 [get_ports {GPIO_3_tri_io[23]}]
set_property PACKAGE_PIN H16 [get_ports {GPIO_3_tri_io[24]}]
set_property PACKAGE_PIN G16 [get_ports {GPIO_3_tri_io[25]}]
set_property PACKAGE_PIN B24 [get_ports {GPIO_3_tri_io[26]}]
set_property PACKAGE_PIN C24 [get_ports {GPIO_3_tri_io[27]}]
set_property PACKAGE_PIN D20 [get_ports {GPIO_3_tri_io[28]}]
set_property PACKAGE_PIN E20 [get_ports {GPIO_3_tri_io[29]}]
set_property PACKAGE_PIN C22 [get_ports {GPIO_3_tri_io[30]}]
set_property PACKAGE_PIN C23 [get_ports {GPIO_3_tri_io[31]}]

set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_3_tri_io[31]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_3_tri_io[30]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_3_tri_io[29]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_3_tri_io[28]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_3_tri_io[27]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_3_tri_io[26]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_3_tri_io[25]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_3_tri_io[24]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_3_tri_io[23]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_3_tri_io[22]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_3_tri_io[21]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_3_tri_io[20]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_3_tri_io[19]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_3_tri_io[18]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_3_tri_io[17]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_3_tri_io[16]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_3_tri_io[15]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_3_tri_io[14]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_3_tri_io[13]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_3_tri_io[12]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_3_tri_io[11]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_3_tri_io[10]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_3_tri_io[9]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_3_tri_io[8]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_3_tri_io[7]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_3_tri_io[6]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_3_tri_io[5]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_3_tri_io[4]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_3_tri_io[3]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_3_tri_io[2]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_3_tri_io[1]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_3_tri_io[0]}]

set_property PULLDOWN true [get_ports {GPIO_3_tri_io[30]}]
set_property PULLDOWN true [get_ports {GPIO_3_tri_io[29]}]
set_property PULLDOWN true [get_ports {GPIO_3_tri_io[28]}]
set_property PULLDOWN true [get_ports {GPIO_3_tri_io[27]}]
set_property PULLDOWN true [get_ports {GPIO_3_tri_io[26]}]
set_property PULLDOWN true [get_ports {GPIO_3_tri_io[25]}]
set_property PULLDOWN true [get_ports {GPIO_3_tri_io[24]}]
set_property PULLDOWN true [get_ports {GPIO_3_tri_io[23]}]
set_property PULLDOWN true [get_ports {GPIO_3_tri_io[22]}]
set_property PULLDOWN true [get_ports {GPIO_3_tri_io[21]}]
set_property PULLDOWN true [get_ports {GPIO_3_tri_io[20]}]
set_property PULLDOWN true [get_ports {GPIO_3_tri_io[19]}]
set_property PULLDOWN true [get_ports {GPIO_3_tri_io[18]}]
set_property PULLDOWN true [get_ports {GPIO_3_tri_io[17]}]
set_property PULLDOWN true [get_ports {GPIO_3_tri_io[16]}]
set_property PULLDOWN true [get_ports {GPIO_3_tri_io[15]}]
set_property PULLDOWN true [get_ports {GPIO_3_tri_io[14]}]
set_property PULLDOWN true [get_ports {GPIO_3_tri_io[13]}]
set_property PULLDOWN true [get_ports {GPIO_3_tri_io[12]}]
set_property PULLDOWN true [get_ports {GPIO_3_tri_io[11]}]
set_property PULLDOWN true [get_ports {GPIO_3_tri_io[10]}]
set_property PULLDOWN true [get_ports {GPIO_3_tri_io[9]}]
set_property PULLDOWN true [get_ports {GPIO_3_tri_io[8]}]
set_property PULLDOWN true [get_ports {GPIO_3_tri_io[7]}]
set_property PULLDOWN true [get_ports {GPIO_3_tri_io[6]}]
set_property PULLDOWN true [get_ports {GPIO_3_tri_io[5]}]
set_property PULLDOWN true [get_ports {GPIO_3_tri_io[4]}]
set_property PULLDOWN true [get_ports {GPIO_3_tri_io[3]}]
set_property PULLDOWN true [get_ports {GPIO_3_tri_io[2]}]
set_property PULLDOWN true [get_ports {GPIO_3_tri_io[1]}]
set_property PULLDOWN true [get_ports {GPIO_3_tri_io[0]}]
#------------------------------------------------------------------

#GPIO_4
set_property PACKAGE_PIN K21 [get_ports {GPIO_4_tri_io[0]}]
set_property PACKAGE_PIN J21 [get_ports {GPIO_4_tri_io[1]}]
set_property PACKAGE_PIN F24 [get_ports {GPIO_4_tri_io[2]}]
set_property PACKAGE_PIN G24 [get_ports {GPIO_4_tri_io[3]}]
set_property PACKAGE_PIN H19 [get_ports {GPIO_4_tri_io[4]}]
set_property PACKAGE_PIN J19 [get_ports {GPIO_4_tri_io[5]}]
set_property PACKAGE_PIN G21 [get_ports {GPIO_4_tri_io[6]}]
set_property PACKAGE_PIN G20 [get_ports {GPIO_4_tri_io[7]}]
set_property PACKAGE_PIN M16 [get_ports {GPIO_4_tri_io[8]}]
set_property PACKAGE_PIN M17 [get_ports {GPIO_4_tri_io[9]}]
set_property PACKAGE_PIN J20 [get_ports {GPIO_4_tri_io[10]}]
set_property PACKAGE_PIN K20 [get_ports {GPIO_4_tri_io[11]}]
set_property PACKAGE_PIN K22 [get_ports {GPIO_4_tri_io[12]}]
set_property PACKAGE_PIN K23 [get_ports {GPIO_4_tri_io[13]}]
set_property PACKAGE_PIN H22 [get_ports {GPIO_4_tri_io[14]}]
set_property PACKAGE_PIN H21 [get_ports {GPIO_4_tri_io[15]}]
set_property PACKAGE_PIN H18 [get_ports {GPIO_4_tri_io[16]}]
set_property PACKAGE_PIN J18 [get_ports {GPIO_4_tri_io[17]}]
set_property PACKAGE_PIN H23 [get_ports {GPIO_4_tri_io[18]}]
set_property PACKAGE_PIN J23 [get_ports {GPIO_4_tri_io[19]}]
set_property PACKAGE_PIN L15 [get_ports {GPIO_4_tri_io[20]}]
set_property PACKAGE_PIN M15 [get_ports {GPIO_4_tri_io[21]}]
set_property PACKAGE_PIN H24 [get_ports {GPIO_4_tri_io[22]}]
set_property PACKAGE_PIN J24 [get_ports {GPIO_4_tri_io[23]}]
set_property PACKAGE_PIN F25 [get_ports {GPIO_4_tri_io[24]}]
set_property PACKAGE_PIN G25 [get_ports {GPIO_4_tri_io[25]}]
set_property PACKAGE_PIN M14 [get_ports {GPIO_4_tri_io[26]}]
set_property PACKAGE_PIN L14 [get_ports {GPIO_4_tri_io[27]}]
set_property PACKAGE_PIN J25 [get_ports {GPIO_4_tri_io[28]}]
set_property PACKAGE_PIN F22 [get_ports {GPIO_4_tri_io[29]}]
set_property PACKAGE_PIN G22 [get_ports {GPIO_4_tri_io[30]}]
set_property PACKAGE_PIN E23 [get_ports {GPIO_4_tri_io[31]}]

set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_4_tri_io[31]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_4_tri_io[30]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_4_tri_io[29]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_4_tri_io[28]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_4_tri_io[27]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_4_tri_io[26]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_4_tri_io[25]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_4_tri_io[24]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_4_tri_io[23]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_4_tri_io[22]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_4_tri_io[21]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_4_tri_io[20]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_4_tri_io[19]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_4_tri_io[18]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_4_tri_io[17]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_4_tri_io[16]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_4_tri_io[15]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_4_tri_io[14]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_4_tri_io[13]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_4_tri_io[12]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_4_tri_io[11]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_4_tri_io[10]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_4_tri_io[9]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_4_tri_io[8]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_4_tri_io[7]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_4_tri_io[6]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_4_tri_io[5]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_4_tri_io[4]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_4_tri_io[3]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_4_tri_io[2]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_4_tri_io[1]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_4_tri_io[0]}]

set_property PULLDOWN true [get_ports {GPIO_4_tri_io[31]}]
set_property PULLDOWN true [get_ports {GPIO_4_tri_io[30]}]
set_property PULLDOWN true [get_ports {GPIO_4_tri_io[29]}]
set_property PULLDOWN true [get_ports {GPIO_4_tri_io[28]}]
set_property PULLDOWN true [get_ports {GPIO_4_tri_io[27]}]
set_property PULLDOWN true [get_ports {GPIO_4_tri_io[26]}]
set_property PULLDOWN true [get_ports {GPIO_4_tri_io[25]}]
set_property PULLDOWN true [get_ports {GPIO_4_tri_io[24]}]
set_property PULLDOWN true [get_ports {GPIO_4_tri_io[23]}]
set_property PULLDOWN true [get_ports {GPIO_4_tri_io[22]}]
set_property PULLDOWN true [get_ports {GPIO_4_tri_io[21]}]
set_property PULLDOWN true [get_ports {GPIO_4_tri_io[20]}]
set_property PULLDOWN true [get_ports {GPIO_4_tri_io[19]}]
set_property PULLDOWN true [get_ports {GPIO_4_tri_io[18]}]
set_property PULLDOWN true [get_ports {GPIO_4_tri_io[17]}]
set_property PULLDOWN true [get_ports {GPIO_4_tri_io[16]}]
set_property PULLDOWN true [get_ports {GPIO_4_tri_io[15]}]
set_property PULLDOWN true [get_ports {GPIO_4_tri_io[14]}]
set_property PULLDOWN true [get_ports {GPIO_4_tri_io[13]}]
set_property PULLDOWN true [get_ports {GPIO_4_tri_io[12]}]
set_property PULLDOWN true [get_ports {GPIO_4_tri_io[11]}]
set_property PULLDOWN true [get_ports {GPIO_4_tri_io[10]}]
set_property PULLDOWN true [get_ports {GPIO_4_tri_io[9]}]
set_property PULLDOWN true [get_ports {GPIO_4_tri_io[8]}]
set_property PULLDOWN true [get_ports {GPIO_4_tri_io[7]}]
set_property PULLDOWN true [get_ports {GPIO_4_tri_io[6]}]
set_property PULLDOWN true [get_ports {GPIO_4_tri_io[5]}]
set_property PULLDOWN true [get_ports {GPIO_4_tri_io[4]}]
set_property PULLDOWN true [get_ports {GPIO_4_tri_io[3]}]
set_property PULLDOWN true [get_ports {GPIO_4_tri_io[2]}]
set_property PULLDOWN true [get_ports {GPIO_4_tri_io[1]}]
set_property PULLDOWN true [get_ports {GPIO_4_tri_io[0]}]
#------------------------------------------------------------------

#GPIO_5
set_property PACKAGE_PIN F23 [get_ports {GPIO_5_tri_io[0]}]
set_property PACKAGE_PIN D25 [get_ports {GPIO_5_tri_io[1]}]
set_property PACKAGE_PIN E25 [get_ports {GPIO_5_tri_io[2]}]
set_property PACKAGE_PIN E26 [get_ports {GPIO_5_tri_io[3]}]
set_property PACKAGE_PIN D26 [get_ports {GPIO_5_tri_io[4]}]
set_property PACKAGE_PIN H26 [get_ports {GPIO_5_tri_io[5]}]
set_property PACKAGE_PIN G26 [get_ports {GPIO_5_tri_io[6]}]
set_property PACKAGE_PIN L17 [get_ports {GPIO_5_tri_io[7]}]
set_property PACKAGE_PIN L18 [get_ports {GPIO_5_tri_io[8]}]
set_property PACKAGE_PIN AB24 [get_ports {GPIO_5_tri_io[9]}]
set_property PACKAGE_PIN AC24 [get_ports {GPIO_5_tri_io[10]}]
set_property PACKAGE_PIN AD19 [get_ports {GPIO_5_tri_io[11]}]
set_property PACKAGE_PIN AC19 [get_ports {GPIO_5_tri_io[12]}]
set_property PACKAGE_PIN W20 [get_ports {GPIO_5_tri_io[13]}]
set_property PACKAGE_PIN Y20 [get_ports {GPIO_5_tri_io[14]}]
set_property PACKAGE_PIN T18 [get_ports {GPIO_5_tri_io[15]}]
set_property PACKAGE_PIN T17 [get_ports {GPIO_5_tri_io[16]}]
set_property PACKAGE_PIN W25 [get_ports {GPIO_5_tri_io[17]}]
set_property PACKAGE_PIN Y26 [get_ports {GPIO_5_tri_io[18]}]
set_property PACKAGE_PIN AD20 [get_ports {GPIO_5_tri_io[19]}]
set_property PACKAGE_PIN AE20 [get_ports {GPIO_5_tri_io[20]}]
set_property PACKAGE_PIN W21 [get_ports {GPIO_5_tri_io[21]}]
set_property PACKAGE_PIN Y21 [get_ports {GPIO_5_tri_io[22]}]
set_property PACKAGE_PIN AB25 [get_ports {GPIO_5_tri_io[23]}]
set_property PACKAGE_PIN AA24 [get_ports {GPIO_5_tri_io[24]}]
set_property PACKAGE_PIN AE22 [get_ports {GPIO_5_tri_io[25]}]
set_property PACKAGE_PIN AF22 [get_ports {GPIO_5_tri_io[26]}]
set_property PACKAGE_PIN T14 [get_ports {GPIO_5_tri_io[27]}]
set_property PACKAGE_PIN T15 [get_ports {GPIO_5_tri_io[28]}]
set_property PACKAGE_PIN T20 [get_ports {GPIO_5_tri_io[29]}]
set_property PACKAGE_PIN U20 [get_ports {GPIO_5_tri_io[30]}]
set_property PACKAGE_PIN N23 [get_ports {GPIO_5_tri_io[31]}]

set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_5_tri_io[31]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_5_tri_io[30]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_5_tri_io[29]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_5_tri_io[28]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_5_tri_io[27]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_5_tri_io[26]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_5_tri_io[25]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_5_tri_io[24]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_5_tri_io[23]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_5_tri_io[22]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_5_tri_io[21]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_5_tri_io[20]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_5_tri_io[19]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_5_tri_io[18]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_5_tri_io[17]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_5_tri_io[16]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_5_tri_io[15]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_5_tri_io[14]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_5_tri_io[13]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_5_tri_io[12]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_5_tri_io[11]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_5_tri_io[10]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_5_tri_io[9]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_5_tri_io[8]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_5_tri_io[7]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_5_tri_io[6]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_5_tri_io[5]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_5_tri_io[4]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_5_tri_io[3]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_5_tri_io[2]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_5_tri_io[1]}]
set_property IOSTANDARD LVCMOS33 [get_ports {GPIO_5_tri_io[0]}]

set_property PULLDOWN true [get_ports {GPIO_5_tri_io[30]}]
set_property PULLDOWN true [get_ports {GPIO_5_tri_io[29]}]
set_property PULLDOWN true [get_ports {GPIO_5_tri_io[28]}]
set_property PULLDOWN true [get_ports {GPIO_5_tri_io[27]}]
set_property PULLDOWN true [get_ports {GPIO_5_tri_io[26]}]
set_property PULLDOWN true [get_ports {GPIO_5_tri_io[25]}]
set_property PULLDOWN true [get_ports {GPIO_5_tri_io[24]}]
set_property PULLDOWN true [get_ports {GPIO_5_tri_io[23]}]
set_property PULLDOWN true [get_ports {GPIO_5_tri_io[22]}]
set_property PULLDOWN true [get_ports {GPIO_5_tri_io[21]}]
set_property PULLDOWN true [get_ports {GPIO_5_tri_io[20]}]
set_property PULLDOWN true [get_ports {GPIO_5_tri_io[19]}]
set_property PULLDOWN true [get_ports {GPIO_5_tri_io[18]}]
set_property PULLDOWN true [get_ports {GPIO_5_tri_io[17]}]
set_property PULLDOWN true [get_ports {GPIO_5_tri_io[16]}]
set_property PULLDOWN true [get_ports {GPIO_5_tri_io[15]}]
set_property PULLDOWN true [get_ports {GPIO_5_tri_io[14]}]
set_property PULLDOWN true [get_ports {GPIO_5_tri_io[13]}]
set_property PULLDOWN true [get_ports {GPIO_5_tri_io[12]}]
set_property PULLDOWN true [get_ports {GPIO_5_tri_io[11]}]
set_property PULLDOWN true [get_ports {GPIO_5_tri_io[10]}]
set_property PULLDOWN true [get_ports {GPIO_5_tri_io[9]}]
set_property PULLDOWN true [get_ports {GPIO_5_tri_io[8]}]
set_property PULLDOWN true [get_ports {GPIO_5_tri_io[7]}]
set_property PULLDOWN true [get_ports {GPIO_5_tri_io[6]}]
set_property PULLDOWN true [get_ports {GPIO_5_tri_io[5]}]
set_property PULLDOWN true [get_ports {GPIO_5_tri_io[4]}]
set_property PULLDOWN true [get_ports {GPIO_5_tri_io[3]}]
set_property PULLDOWN true [get_ports {GPIO_5_tri_io[2]}]
set_property PULLDOWN true [get_ports {GPIO_5_tri_io[1]}]
set_property PULLDOWN true [get_ports {GPIO_5_tri_io[0]}]
#------------------------------------------------------------------

#------------------------------------------------------------------------------------------------------------------------------------
# GTP Quad Timing and Pin Configuration
#------------------------------------------------------------------------------------------------------------------------------------

create_clock -period 8.000 -name gtp_refclk1 -waveform {0.000 4.000} [get_ports {GT_DIFF_REFCLK1_clk_p}]
create_clock -period 8.000 -name gtp_refclk2 -waveform {0.000 4.000} [get_ports {GT_DIFF_REFCLK2_clk_p}]

# Default
# -------------------------------------------
# ------------- GTP QUAD_213 TX -------------
# ------------- GTP QUAD_216 RX -------------
# -------------------------------------------

# ------------- GTP QUAD_213 TX -------------
set_property PACKAGE_PIN AA13 [get_ports GT_DIFF_REFCLK2_clk_p]

set_property PACKAGE_PIN AF9 [get_ports {gt0_tx0_txn[0]}]
set_property PACKAGE_PIN AD8 [get_ports {gt0_tx0_txn[1]}]
set_property PACKAGE_PIN AF7 [get_ports {gt0_tx0_txn[2]}]
set_property PACKAGE_PIN AD10 [get_ports {gt0_tx0_txn[3]}]

# ------------- GTP QUAD_216 RX -------------
set_property PACKAGE_PIN F11 [get_ports GT_DIFF_REFCLK1_clk_p]

set_property PACKAGE_PIN A11 [get_ports {gt0_rx0_rxn[0]}]
set_property PACKAGE_PIN C14 [get_ports {gt0_rx0_rxn[1]}]
set_property PACKAGE_PIN A13 [get_ports {gt0_rx0_rxn[2]}]
set_property PACKAGE_PIN C12 [get_ports {gt0_rx0_rxn[3]}]

## -------------------------------------------
## ------------- GTP QUAD_216 TX -------------
## ------------- GTP QUAD_213 RX -------------
## -------------------------------------------
## Uncomment following lines to use GTP QUAD_216 as TX and QUAD_213 as RX
## ------------- GTP QUAD_216 TX -------------
#set_property PACKAGE_PIN F11 [get_ports GT_DIFF_REFCLK2_clk_p]

#set_property PACKAGE_PIN A7 [get_ports {gt0_tx0_txn[0]}]
#set_property PACKAGE_PIN C10 [get_ports {gt0_tx0_txn[1]}]
#set_property PACKAGE_PIN C8 [get_ports {gt0_tx0_txn[2]}]
#set_property PACKAGE_PIN A9 [get_ports {gt0_tx0_txn[3]}]

## ------------- GTP QUAD_213 RX -------------
#set_property PACKAGE_PIN AA13 [get_ports GT_DIFF_REFCLK1_clk_p]

#set_property PACKAGE_PIN AD12 [get_ports {gt0_rx0_rxn[0]}]
#set_property PACKAGE_PIN AF13 [get_ports {gt0_rx0_rxn[1]}]
#set_property PACKAGE_PIN AD14 [get_ports {gt0_rx0_rxn[2]}]
#set_property PACKAGE_PIN AF11 [get_ports {gt0_rx0_rxn[3]}]

#------------------------------------------------------------------------------------------------------------------------------------
## Configuration Mode
#------------------------------------------------------------------------------------------------------------------------------------
# Slave_Select_Map (Default)
# FPGA will be configured via USB; FPGA is Slave.
set_property CONFIG_MODE S_SELECTMAP16 [current_design]
set_property BITSTREAM.CONFIG.EXTMASTERCCLK_EN DIV-1 [current_design]

## SPI based Flash Memory
## FPGA will be configured via Flash Memory; FPGA is Master.
## Uncomment the following 4 lines to configure FPGA from Flash.
#set_property CONFIG_MODE SPIx4 [current_design]
#set_property BITSTREAM.CONFIG.SPI_FALL_EDGE YES [current_design]
#set_property BITSTREAM.CONFIG.EXTMASTERCCLK_EN DIV-1 [current_design]
#set_property BITSTREAM.CONFIG.SPI_BUSWIDTH 4 [current_design]
#------------------------------------------------------------------------------------------------------------------------------------


#------------------------------------------------------------------------------------------------------------------------------------
## Maximum delays in clock-domain crossing
#------------------------------------------------------------------------------------------------------------------------------------
set_max_delay -datapath_only -from [get_clocks -of_objects [get_pins efm03_i/mig_7series_0/u_efm03_mig_7series_0_0_mig/u_ddr3_infrastructure/gen_mmcm.mmcm_i/CLKFBOUT]] -to [get_clocks *i_fx3_pclk] 10.000
set_max_delay -datapath_only -from [get_clocks efm03_i/gtp_ss/Simplex_RX/U0/efm03_Simplex_RX_0_core_i/gt_wrapper_i/efm03_Simplex_RX_0_multi_gt_i/gt2_efm03_Simplex_RX_0_i/gtpe2_i/TXOUTCLK] -to [get_clocks -of_objects [get_pins efm03_i/mig_7series_0/u_efm03_mig_7series_0_0_mig/u_ddr3_infrastructure/gen_mmcm.mmcm_i/CLKFBOUT]] 5.000
set_max_delay -datapath_only -from [get_clocks efm03_i/gtp_ss/Simplex_RX/U0/efm03_Simplex_RX_0_core_i/gt_wrapper_i/efm03_Simplex_RX_0_multi_gt_i/gt2_efm03_Simplex_RX_0_i/gtpe2_i/TXOUTCLK] -to [get_clocks efm03_i/gtp_ss/Simplex_TX/U0/efm03_Simplex_TX_0_core_i/gt_wrapper_i/efm03_Simplex_TX_0_multi_gt_i/gt2_efm03_Simplex_TX_0_i/gtpe2_i/TXOUTCLK] 4.000
set_max_delay -datapath_only -from [get_clocks efm03_i/gtp_ss/Simplex_TX/U0/efm03_Simplex_TX_0_core_i/gt_wrapper_i/efm03_Simplex_TX_0_multi_gt_i/gt2_efm03_Simplex_TX_0_i/gtpe2_i/TXOUTCLK] -to [get_clocks -of_objects [get_pins efm03_i/mig_7series_0/u_efm03_mig_7series_0_0_mig/u_ddr3_infrastructure/gen_mmcm.mmcm_i/CLKFBOUT]] 5.000

set_max_delay -datapath_only -from [get_clocks i_fx3_pclk] -to [get_clocks o_fx3_pclk] 10.000
